# Timezones List

**Last Update: 2024-12-14**


1. Africa/Abidjan
2. Africa/Accra
3. Africa/Addis_Ababa
4. Africa/Algiers
5. Africa/Asmara
6. Africa/Asmera
7. Africa/Bamako
8. Africa/Bangui
9. Africa/Banjul
10. Africa/Bissau
11. Africa/Blantyre
12. Africa/Brazzaville
13. Africa/Bujumbura
14. Africa/Cairo
15. Africa/Casablanca
16. Africa/Ceuta
17. Africa/Conakry
18. Africa/Dakar
19. Africa/Dar_es_Salaam
20. Africa/Djibouti
21. Africa/Douala
22. Africa/El_Aaiun
23. Africa/Freetown
24. Africa/Gaborone
25. Africa/Harare
26. Africa/Johannesburg
27. Africa/Juba
28. Africa/Kampala
29. Africa/Khartoum
30. Africa/Kigali
31. Africa/Kinshasa
32. Africa/Lagos
33. Africa/Libreville
34. Africa/Lome
35. Africa/Luanda
36. Africa/Lubumbashi
37. Africa/Lusaka
38. Africa/Malabo
39. Africa/Maputo
40. Africa/Maseru
41. Africa/Mbabane
42. Africa/Mogadishu
43. Africa/Monrovia
44. Africa/Nairobi
45. Africa/Ndjamena
46. Africa/Niamey
47. Africa/Nouakchott
48. Africa/Ouagadougou
49. Africa/Porto-Novo
50. Africa/Sao_Tome
51. Africa/Timbuktu
52. Africa/Tripoli
53. Africa/Tunis
54. Africa/Windhoek
55. America/Adak
56. America/Anchorage
57. America/Anguilla
58. America/Antigua
59. America/Araguaina
60. America/Argentina/Buenos_Aires
61. America/Argentina/Catamarca
62. America/Argentina/ComodRivadavia
63. America/Argentina/Cordoba
64. America/Argentina/Jujuy
65. America/Argentina/La_Rioja
66. America/Argentina/Mendoza
67. America/Argentina/Rio_Gallegos
68. America/Argentina/Salta
69. America/Argentina/San_Juan
70. America/Argentina/San_Luis
71. America/Argentina/Tucuman
72. America/Argentina/Ushuaia
73. America/Aruba
74. America/Asuncion
75. America/Atikokan
76. America/Atka
77. America/Bahia
78. America/Bahia_Banderas
79. America/Barbados
80. America/Belem
81. America/Belize
82. America/Blanc-Sablon
83. America/Boa_Vista
84. America/Bogota
85. America/Boise
86. America/Buenos_Aires
87. America/Cambridge_Bay
88. America/Campo_Grande
89. America/Cancun
90. America/Caracas
91. America/Catamarca
92. America/Cayenne
93. America/Cayman
94. America/Chicago
95. America/Chihuahua
96. America/Ciudad_Juarez
97. America/Coral_Harbour
98. America/Cordoba
99. America/Costa_Rica
100. America/Creston
101. America/Cuiaba
102. America/Curacao
103. America/Danmarkshavn
104. America/Dawson
105. America/Dawson_Creek
106. America/Denver
107. America/Detroit
108. America/Dominica
109. America/Edmonton
110. America/Eirunepe
111. America/El_Salvador
112. America/Ensenada
113. America/Fort_Nelson
114. America/Fort_Wayne
115. America/Fortaleza
116. America/Glace_Bay
117. America/Godthab
118. America/Goose_Bay
119. America/Grand_Turk
120. America/Grenada
121. America/Guadeloupe
122. America/Guatemala
123. America/Guayaquil
124. America/Guyana
125. America/Halifax
126. America/Havana
127. America/Hermosillo
128. America/Indiana/Indianapolis
129. America/Indiana/Knox
130. America/Indiana/Marengo
131. America/Indiana/Petersburg
132. America/Indiana/Tell_City
133. America/Indiana/Vevay
134. America/Indiana/Vincennes
135. America/Indiana/Winamac
136. America/Indianapolis
137. America/Inuvik
138. America/Iqaluit
139. America/Jamaica
140. America/Jujuy
141. America/Juneau
142. America/Kentucky/Louisville
143. America/Kentucky/Monticello
144. America/Knox_IN
145. America/Kralendijk
146. America/La_Paz
147. America/Lima
148. America/Los_Angeles
149. America/Louisville
150. America/Lower_Princes
151. America/Maceio
152. America/Managua
153. America/Manaus
154. America/Marigot
155. America/Martinique
156. America/Matamoros
157. America/Mazatlan
158. America/Mendoza
159. America/Menominee
160. America/Merida
161. America/Metlakatla
162. America/Mexico_City
163. America/Miquelon
164. America/Moncton
165. America/Monterrey
166. America/Montevideo
167. America/Montreal
168. America/Montserrat
169. America/Nassau
170. America/New_York
171. America/Nipigon
172. America/Nome
173. America/Noronha
174. America/North_Dakota/Beulah
175. America/North_Dakota/Center
176. America/North_Dakota/New_Salem
177. America/Nuuk
178. America/Ojinaga
179. America/Panama
180. America/Pangnirtung
181. America/Paramaribo
182. America/Phoenix
183. America/Port-au-Prince
184. America/Port_of_Spain
185. America/Porto_Acre
186. America/Porto_Velho
187. America/Puerto_Rico
188. America/Punta_Arenas
189. America/Rainy_River
190. America/Rankin_Inlet
191. America/Recife
192. America/Regina
193. America/Resolute
194. America/Rio_Branco
195. America/Rosario
196. America/Santa_Isabel
197. America/Santarem
198. America/Santiago
199. America/Santo_Domingo
200. America/Sao_Paulo
201. America/Scoresbysund
202. America/Shiprock
203. America/Sitka
204. America/St_Barthelemy
205. America/St_Johns
206. America/St_Kitts
207. America/St_Lucia
208. America/St_Thomas
209. America/St_Vincent
210. America/Swift_Current
211. America/Tegucigalpa
212. America/Thule
213. America/Thunder_Bay
214. America/Tijuana
215. America/Toronto
216. America/Tortola
217. America/Vancouver
218. America/Virgin
219. America/Whitehorse
220. America/Winnipeg
221. America/Yakutat
222. America/Yellowknife
223. Antarctica/Casey
224. Antarctica/Davis
225. Antarctica/DumontDUrville
226. Antarctica/Macquarie
227. Antarctica/Mawson
228. Antarctica/McMurdo
229. Antarctica/Palmer
230. Antarctica/Rothera
231. Antarctica/South_Pole
232. Antarctica/Syowa
233. Antarctica/Troll
234. Antarctica/Vostok
235. Arctic/Longyearbyen
236. Asia/Aden
237. Asia/Almaty
238. Asia/Amman
239. Asia/Anadyr
240. Asia/Aqtau
241. Asia/Aqtobe
242. Asia/Ashgabat
243. Asia/Ashkhabad
244. Asia/Atyrau
245. Asia/Baghdad
246. Asia/Bahrain
247. Asia/Baku
248. Asia/Bangkok
249. Asia/Barnaul
250. Asia/Beirut
251. Asia/Bishkek
252. Asia/Brunei
253. Asia/Calcutta
254. Asia/Chita
255. Asia/Choibalsan
256. Asia/Chongqing
257. Asia/Chungking
258. Asia/Colombo
259. Asia/Dacca
260. Asia/Damascus
261. Asia/Dhaka
262. Asia/Dili
263. Asia/Dubai
264. Asia/Dushanbe
265. Asia/Famagusta
266. Asia/Gaza
267. Asia/Harbin
268. Asia/Hebron
269. Asia/Ho_Chi_Minh
270. Asia/Hong_Kong
271. Asia/Hovd
272. Asia/Irkutsk
273. Asia/Istanbul
274. Asia/Jakarta
275. Asia/Jayapura
276. Asia/Jerusalem
277. Asia/Kabul
278. Asia/Kamchatka
279. Asia/Karachi
280. Asia/Kashgar
281. Asia/Kathmandu
282. Asia/Katmandu
283. Asia/Khandyga
284. Asia/Kolkata
285. Asia/Krasnoyarsk
286. Asia/Kuala_Lumpur
287. Asia/Kuching
288. Asia/Kuwait
289. Asia/Macao
290. Asia/Macau
291. Asia/Magadan
292. Asia/Makassar
293. Asia/Manila
294. Asia/Muscat
295. Asia/Nicosia
296. Asia/Novokuznetsk
297. Asia/Novosibirsk
298. Asia/Omsk
299. Asia/Oral
300. Asia/Phnom_Penh
301. Asia/Pontianak
302. Asia/Pyongyang
303. Asia/Qatar
304. Asia/Qostanay
305. Asia/Qyzylorda
306. Asia/Rangoon
307. Asia/Riyadh
308. Asia/Saigon
309. Asia/Sakhalin
310. Asia/Samarkand
311. Asia/Seoul
312. Asia/Shanghai
313. Asia/Singapore
314. Asia/Srednekolymsk
315. Asia/Taipei
316. Asia/Tashkent
317. Asia/Tbilisi
318. Asia/Tehran
319. Asia/Tel_Aviv
320. Asia/Thimbu
321. Asia/Thimphu
322. Asia/Tokyo
323. Asia/Tomsk
324. Asia/Ujung_Pandang
325. Asia/Ulaanbaatar
326. Asia/Ulan_Bator
327. Asia/Urumqi
328. Asia/Ust-Nera
329. Asia/Vientiane
330. Asia/Vladivostok
331. Asia/Yakutsk
332. Asia/Yangon
333. Asia/Yekaterinburg
334. Asia/Yerevan
335. Atlantic/Azores
336. Atlantic/Bermuda
337. Atlantic/Canary
338. Atlantic/Cape_Verde
339. Atlantic/Faeroe
340. Atlantic/Faroe
341. Atlantic/Jan_Mayen
342. Atlantic/Madeira
343. Atlantic/Reykjavik
344. Atlantic/South_Georgia
345. Atlantic/St_Helena
346. Atlantic/Stanley
347. Australia/ACT
348. Australia/Adelaide
349. Australia/Brisbane
350. Australia/Broken_Hill
351. Australia/Canberra
352. Australia/Currie
353. Australia/Darwin
354. Australia/Eucla
355. Australia/Hobart
356. Australia/LHI
357. Australia/Lindeman
358. Australia/Lord_Howe
359. Australia/Melbourne
360. Australia/NSW
361. Australia/North
362. Australia/Perth
363. Australia/Queensland
364. Australia/South
365. Australia/Sydney
366. Australia/Tasmania
367. Australia/Victoria
368. Australia/West
369. Australia/Yancowinna
370. Brazil/Acre
371. Brazil/DeNoronha
372. Brazil/East
373. Brazil/West
374. CET
375. CST6CDT
376. Canada/Atlantic
377. Canada/Central
378. Canada/Eastern
379. Canada/Mountain
380. Canada/Newfoundland
381. Canada/Pacific
382. Canada/Saskatchewan
383. Canada/Yukon
384. Chile/Continental
385. Chile/EasterIsland
386. Cuba
387. EET
388. EST
389. EST5EDT
390. Egypt
391. Eire
392. Etc/GMT
393. Etc/GMT+0
394. Etc/GMT+1
395. Etc/GMT+10
396. Etc/GMT+11
397. Etc/GMT+12
398. Etc/GMT+2
399. Etc/GMT+3
400. Etc/GMT+4
401. Etc/GMT+5
402. Etc/GMT+6
403. Etc/GMT+7
404. Etc/GMT+8
405. Etc/GMT+9
406. Etc/GMT-0
407. Etc/GMT-1
408. Etc/GMT-10
409. Etc/GMT-11
410. Etc/GMT-12
411. Etc/GMT-13
412. Etc/GMT-14
413. Etc/GMT-2
414. Etc/GMT-3
415. Etc/GMT-4
416. Etc/GMT-5
417. Etc/GMT-6
418. Etc/GMT-7
419. Etc/GMT-8
420. Etc/GMT-9
421. Etc/GMT0
422. Etc/Greenwich
423. Etc/UCT
424. Etc/UTC
425. Etc/Universal
426. Etc/Zulu
427. Europe/Amsterdam
428. Europe/Andorra
429. Europe/Astrakhan
430. Europe/Athens
431. Europe/Belfast
432. Europe/Belgrade
433. Europe/Berlin
434. Europe/Bratislava
435. Europe/Brussels
436. Europe/Bucharest
437. Europe/Budapest
438. Europe/Busingen
439. Europe/Chisinau
440. Europe/Copenhagen
441. Europe/Dublin
442. Europe/Gibraltar
443. Europe/Guernsey
444. Europe/Helsinki
445. Europe/Isle_of_Man
446. Europe/Istanbul
447. Europe/Jersey
448. Europe/Kaliningrad
449. Europe/Kiev
450. Europe/Kirov
451. Europe/Kyiv
452. Europe/Lisbon
453. Europe/Ljubljana
454. Europe/London
455. Europe/Luxembourg
456. Europe/Madrid
457. Europe/Malta
458. Europe/Mariehamn
459. Europe/Minsk
460. Europe/Monaco
461. Europe/Moscow
462. Europe/Nicosia
463. Europe/Oslo
464. Europe/Paris
465. Europe/Podgorica
466. Europe/Prague
467. Europe/Riga
468. Europe/Rome
469. Europe/Samara
470. Europe/San_Marino
471. Europe/Sarajevo
472. Europe/Saratov
473. Europe/Simferopol
474. Europe/Skopje
475. Europe/Sofia
476. Europe/Stockholm
477. Europe/Tallinn
478. Europe/Tirane
479. Europe/Tiraspol
480. Europe/Ulyanovsk
481. Europe/Uzhgorod
482. Europe/Vaduz
483. Europe/Vatican
484. Europe/Vienna
485. Europe/Vilnius
486. Europe/Volgograd
487. Europe/Warsaw
488. Europe/Zagreb
489. Europe/Zaporozhye
490. Europe/Zurich
491. GB
492. GB-Eire
493. GMT
494. GMT+0
495. GMT-0
496. GMT0
497. Greenwich
498. HST
499. Hongkong
500. Iceland
501. Indian/Antananarivo
502. Indian/Chagos
503. Indian/Christmas
504. Indian/Cocos
505. Indian/Comoro
506. Indian/Kerguelen
507. Indian/Mahe
508. Indian/Maldives
509. Indian/Mauritius
510. Indian/Mayotte
511. Indian/Reunion
512. Iran
513. Israel
514. Jamaica
515. Japan
516. Kwajalein
517. Libya
518. MET
519. MST
520. MST7MDT
521. Mexico/BajaNorte
522. Mexico/BajaSur
523. Mexico/General
524. NZ
525. NZ-CHAT
526. Navajo
527. PRC
528. PST8PDT
529. Pacific/Apia
530. Pacific/Auckland
531. Pacific/Bougainville
532. Pacific/Chatham
533. Pacific/Chuuk
534. Pacific/Easter
535. Pacific/Efate
536. Pacific/Enderbury
537. Pacific/Fakaofo
538. Pacific/Fiji
539. Pacific/Funafuti
540. Pacific/Galapagos
541. Pacific/Gambier
542. Pacific/Guadalcanal
543. Pacific/Guam
544. Pacific/Honolulu
545. Pacific/Johnston
546. Pacific/Kanton
547. Pacific/Kiritimati
548. Pacific/Kosrae
549. Pacific/Kwajalein
550. Pacific/Majuro
551. Pacific/Marquesas
552. Pacific/Midway
553. Pacific/Nauru
554. Pacific/Niue
555. Pacific/Norfolk
556. Pacific/Noumea
557. Pacific/Pago_Pago
558. Pacific/Palau
559. Pacific/Pitcairn
560. Pacific/Pohnpei
561. Pacific/Ponape
562. Pacific/Port_Moresby
563. Pacific/Rarotonga
564. Pacific/Saipan
565. Pacific/Samoa
566. Pacific/Tahiti
567. Pacific/Tarawa
568. Pacific/Tongatapu
569. Pacific/Truk
570. Pacific/Wake
571. Pacific/Wallis
572. Pacific/Yap
573. Poland
574. Portugal
575. ROC
576. ROK
577. Singapore
578. Turkey
579. UCT
580. US/Alaska
581. US/Aleutian
582. US/Arizona
583. US/Central
584. US/East-Indiana
585. US/Eastern
586. US/Hawaii
587. US/Indiana-Starke
588. US/Michigan
589. US/Mountain
590. US/Pacific
591. US/Samoa
592. UTC
593. Universal
594. W-SU
595. WET
596. Zulu